==> react-molecule-checkbox-field-2.17.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["id", "label", "nodeLabel", "fullWidth", "successText", "errorText", "alertText", "helpText", "onChange", "toggleIcon", "toggleIconOnChange", "disabled"];
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomCheckbox from '@s-ui/react-atom-checkbox';
import { BASE_CLASS } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeCheckboxField = function MoleculeCheckboxField(_ref) {
  var id = _ref.id,
      label = _ref.label,
      nodeLabel = _ref.nodeLabel,
      fullWidth = _ref.fullWidth,
      successText = _ref.successText,
      errorText = _ref.errorText,
      alertText = _ref.alertText,
      helpText = _ref.helpText,
      onChange = _ref.onChange,
      ToggleIcon = _ref.toggleIcon,
      _ref$toggleIconOnChan = _ref.toggleIconOnChange,
      toggleIconOnChange = _ref$toggleIconOnChan === void 0 ? function () {} : _ref$toggleIconOnChan,
      disabled = _ref.disabled,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsxs(MoleculeField, {
      name: id,
      label: label,
      nodeLabel: nodeLabel,
      fullWidth: fullWidth,
      successText: successText,
      errorText: errorText,
      alertText: alertText,
      helpText: helpText,
      onChange: onChange,
      inline: true,
      reverse: true,
      isAligned: true,
      disabled: disabled,
      children: [/*#__PURE__*/_jsx(AtomCheckbox, _extends({
        id: id
      }, props, {
        disabled: disabled
      })), ToggleIcon && /*#__PURE__*/_jsx("span", {
        className: BASE_CLASS + "-toggleIcon",
        onClick: toggleIconOnChange,
        children: /*#__PURE__*/_jsx(ToggleIcon, {})
      })]
    })
  });
};

MoleculeCheckboxField.displayName = 'MoleculeCheckboxField';
export default MoleculeCheckboxField;

==> react-molecule-checkbox-field-4.0.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["id", "label", "nodeLabel", "fullWidth", "successText", "errorText", "alertText", "helpText", "onChange", "disabled"];
import PropTypes from 'prop-types';
import AtomCheckbox, { atomCheckboxStatus, atomCheckboxSizes } from '@s-ui/react-atom-checkbox';
import MoleculeField from '@s-ui/react-molecule-field';
import { BASE_CLASS } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";

var MoleculeCheckboxField = function MoleculeCheckboxField(_ref) {
  var id = _ref.id,
      label = _ref.label,
      nodeLabel = _ref.nodeLabel,
      fullWidth = _ref.fullWidth,
      successText = _ref.successText,
      errorText = _ref.errorText,
      alertText = _ref.alertText,
      helpText = _ref.helpText,
      onChange = _ref.onChange,
      disabled = _ref.disabled,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: label,
      nodeLabel: nodeLabel,
      fullWidth: fullWidth,
      successText: successText,
      errorText: errorText,
      alertText: alertText,
      helpText: helpText,
      onChange: onChange,
      inline: true,
      reverse: true,
      isAligned: true,
      disabled: disabled,
      children: /*#__PURE__*/_jsx(AtomCheckbox, _extends({
        id: id,
        disabled: disabled
      }, props, {
        onChange: onChange
      }))
    })
  });
};

MoleculeCheckboxField.displayName = 'MoleculeCheckboxField';
export default MoleculeCheckboxField;
export { atomCheckboxStatus as moleculeCheckboxFieldStatus, atomCheckboxSizes as moleculeCheckboxFieldSizes };
